Changelog
=========

0.3.1 released 2024-06-21
-------------------------

- resolve missed signal signature change (52fcc11_)

.. _52fcc11: https://github.com/level12/keg-mail/commit/52fcc11


0.3.0 released 2024-06-21
-------------------------

- automatically pass reply-to header to Mailgun (18fb53f_)
- support flask-mail 0.10.0 changes to signal pattern (3cfe430_)

.. _18fb53f: https://github.com/level12/keg-mail/commit/18fb53f
.. _3cfe430: https://github.com/level12/keg-mail/commit/3cfe430


0.2.4 released 2022-11-10
-------------------------

- allow additional mailgun API options to be sent through send (d35e23d_)
- update CI setup and add python 3.10 (5552cd2_)

.. _d35e23d: https://github.com/level12/keg-mail/commit/d35e23d
.. _5552cd2: https://github.com/level12/keg-mail/commit/5552cd2


0.2.3 released 2020-07-22
-------------------------

- Handle timestamps parsed as decimals in Mailgun event JSON (6a03528_)

.. _6a03528: https://github.com/level12/keg-mail/commit/6a03528


0.2.2 released 2020-07-22
-------------------------

- Fix bug in LogStatusWebhook view mixin (8a3ffde_)

.. _8a3ffde: https://github.com/level12/keg-mail/commit/8a3ffde


0.2.1 released 2020-07-22
-------------------------

- Add support for Mailgun REST API and message status tracking (b3b4428_)

.. _b3b4428: https://github.com/level12/keg-mail/commit/b3b4428


0.2.0 released 2020-04-14
-------------------------

- Support Python 3.8 (bfbb945_)

.. _bfbb945: https://github.com/level12/keg-mail/commit/bfbb945


0.1.0 - 2017-03-23
------------------

- Initial Release
